using Gtk;
using GLib;

public class Application : Gtk.Application {

    public static Window window;
    public static GLib.Settings settings;

	public
	Application () {
		Object (application_id: "io.github.julianrichen.boilerplate",
		        flags: ApplicationFlags.FLAGS_NONE);

		settings = new GLib.Settings ("io.github.julianrichen.boilerplate");
	}

	protected override void
	activate () {
		build_app_menu();

		window = new Window(this);
		this.add_window(window);
		window.show_all();
	}

	private void
	build_app_menu () {
		var action = new GLib.SimpleAction ("preferences", null);
		action.activate.connect (() => { this.do_preferences (); });
		this.add_action (action);

		action = new GLib.SimpleAction ("shortcuts", null);
		action.activate.connect (() => { this.do_shortcuts (); });
		this.add_action (action);

		action = new GLib.SimpleAction ("help", null);
		action.activate.connect (() => { this.do_help (); });
		this.add_action (action);

		action = new GLib.SimpleAction ("about", null);
		action.activate.connect (() => { this.do_about (); });
		this.add_action (action);

		action = new GLib.SimpleAction ("quit", null);
		action.activate.connect (() => { this.do_quit (); });
		this.add_action (action);

		var builder = new Gtk.Builder.from_file("resources/ui/app-menu.ui");
		var app_menu = builder.get_object ("app-menu") as GLib.MenuModel;

		set_app_menu (app_menu);
	}

	private void
	do_preferences () {
        print ("Preferences");
	}

	private void
	do_shortcuts () {
        print ("Keyboard Shortcuts");
	}

	private void
	do_help () {
        print ("Help");
	}

	private void
	do_about () {
		string[] authors = {
			"Julian Richen <julian@richen.io>"
		};
		string[] artists = {
			"Julian Richen <julian@richen.io>"
		};

		Gtk.show_about_dialog (
		    window,
			"artists", artists,
			"authors", authors,
			"program-name", "boilerplate",
			"title", _("Boilerplate"),
			"license-type", Gtk.License.GPL_3_0,
			"logo-icon-name", "io.github.julianrichen.boilerplate",
			"version", "0.1.0",
			"website", "https://github.com/julianrichen/boilerplate-for-vala-gtk3",
			"wrap-license", true
		);
	}

	public void
	do_quit () {
		base.quit ();
	}

}
